compute_neighbors_brute: Compute Neighbors Using Brute-Force
Description
Computes neighbors for each point in a set of coordinates using a greedy
approach. All pairwise distances are calculated to identify neighbors within
a specified distance threshold.